@@ -1,5 +1,6 @@
 # coding: utf-8
 
+from valueDict import defaultMarkdown, markdownMap
 import json
 
 import requests
@@ -44,7 +45,7 @@ class DingDingPlugin(NotificationPlugin):
         """
         Process error.
         """
-        print(event.__dict__)
+        print(event.__dict__.data)
         if not self.is_configured(group.project):
             return
 
@@ -53,6 +54,10 @@ class DingDingPlugin(NotificationPlugin):
 
         access_token = self.get_option('access_token', group.project)
         send_url = DingTalk_API.format(token=access_token)
+        customer_markdown = self.get_option('customer_markdown', group.project)
+        if not customer_markdown:
+            customer_markdown = defaultMarkdown
+        print(customer_markdown)
         title = u"New alert from {}".format(event.project.slug)
         linkUrl = u"{}events/{}/".format(group.get_absolute_url(), event.event_id)
 
@@ -67,8 +72,8 @@ class DingDingPlugin(NotificationPlugin):
                 )
             }
         }
-        requests.post(
-            url=send_url,
-            headers={"Content-Type": "application/json"},
-            data=json.dumps(data).encode("utf-8")
-        )
+        # requests.post(
+        #     url=send_url,
+        #     headers={"Content-Type": "application/json"},
+        #     data=json.dumps(data).encode("utf-8")
+        # )
